Package Documentation
=====================

zhinst-toolkit exposes the following classes:

.. autosummary::
   :toctree: _autosummary
   :recursive:

   ~zhinst.toolkit.session.Session
   ~zhinst.toolkit.sequence.Sequence
   ~zhinst.toolkit.waveform.Waveforms
   ~zhinst.toolkit.command_table.CommandTable
   ~zhinst.toolkit.session.PollFlags
   ~zhinst.toolkit.interface.AveragingMode
   ~zhinst.toolkit.interface.SHFQAChannelMode

They can be imported directly from zhinst-toolkit. For example importing the
Session class the following statement can be used:

.. code-block:: python

    >>> from zhinst.toolkit import Session

Full Package Documentation
---------------------------

.. autosummary::
   :toctree: _autosummary
   :recursive:

   zhinst.toolkit

